##GeoFIS=group
##Input_Layer=vector
##Aggregation=selection WAM;OWA;FIS;Function
##Fusion_Layer=output vector

library(GeoFIS)

# R script to aggregate spatial numerical fields
# See the documentation:
# https://www.geofis.org/en/documentation-en/data-fusion/
# https://cran.r-project.org/web/packages/GeoFIS/vignettes/data-fusion.html

fusion <- NewFusion(as_Spatial(Input_Layer))

# We want to aggregate at least 2 numerical fields after assigning a membership function to each of them

# First aggregate input
# the field name in the InputLayer
field1 <- ""
# the fuzzy membership function to turn raw data into preference degrees (object Mf of FisPro R package)
# allowed values are NewMfTriangular, NewMfTrapezoidalInf, NewMfTrapezoidalSup and NewMfTrapezoidal
mf1 <- NewMf...
input1 <- NewFusionInput(field1, mf1)

# Second aggregate input
field2 <- ""
mf2 <- NewMf...
input2 <- NewFusionInput(field2, mf2)

# Next aggregate input(s) (optional)
# field3 <- ""
# mf3 <- NewMf...
# input3 <- NewFusionInput(field3, mf3)

# Aggregation of the fields.
if (Aggregation == 0) {
  wam_weights <- c() # the weights of the WAM operator (vector length = number of inputs, the sum must be equal to 1)
  aggreg <- NewAggregWam(wam_weights)
} else if (Aggregation == 1) {
  owa_weights <- c() # the weights of the OWA operator (vector length = number of inputs, the sum must be equal to 1)
  aggreg <- NewAggregOwa(owa_weights)
} else if (Aggregation == 2) {
  # build a Rule-based aggregation operator (object Fis of FisPro R package)
  fis_file <- "" # the path of the FIS file
  fis <- NewFis(fis_file)
  aggreg <- NewAggregFis(fis)
} else {
  aggreg_function <- mean # the function used to aggregate inputs (function that accepts a numeric vector as parameter, e.g. mean function, or a user-defined function)
  aggreg <- NewAggregFunction(aggreg_function)
}
aggregate <- NewFusionAggreg("aggregation", aggreg, input1, input2) # add all aggregate inputs
fusion$aggregate <- aggregate

fusion$perform()

Fusion_Layer <- st_as_sf(fusion$output())
