##GeoFIS=group
##Aggregation=selection WAM;OWA
##Fusion=output table

library(GeoFIS)

# Example R script to aggregate numerical fields, based on the GeoFIS "fusion_cars" dataset
# Because this dataset is not spatialized, the output is a table
# See the documentation:
# https://www.geofis.org/en/documentation-en/data-fusion/
# https://cran.r-project.org/web/packages/GeoFIS/vignettes/data-fusion.html

data(fusion_cars)
fusion <- NewFusion(fusion_cars)

# We want to aggregate 4 numerical fields (A, V, S, C) after assigning a membership function to each of them
a <- NewFusionInput("a_degree", NewMfTrapezoidalInf(4, 20), "A")
v <- NewFusionInput("v_degree", NewMfTrapezoidalSup(100, 500), "V")
s <- NewFusionInput("s_degree", NewMfTrapezoidalSup(120, 220), "S")
c <- NewFusionInput("c_degree", NewMfTrapezoidalInf(6, 16), "C")

# Aggregation operators (only WAM and OWA operators are implemented)
if (Aggregation == 0) {
  wam_weights <- c(0.5, 0, 0.5, 0)
  aggreg <- NewAggregWam(wam_weights)
} else if (Aggregation == 1) {
  owa_weights <- c(1, 0, 0, 0)
  aggreg <- NewAggregOwa(owa_weights)
}

# Build the aggregate node with the 4 inputs and the "aggreg" operator
aggregate <- NewFusionAggreg("inferred", aggreg, a, v, s, c)
fusion$aggregate <- aggregate

fusion$perform()

Fusion <- fusion$output()
# Open the attribute table of Fusion in QGIS
# the additional field "field_1" is the "rownames" of the R output data.frame
# sort the QGIS attribute table with the field "field_1" to display the Fusion table in the same row order as the input dataset "fusion_cars"
