##GeoFIS=group
##Input_Layer=vector point
##Variable=Field Input_Layer
##Border_Layer= optional vector
##Neighborhood=optional number
##Attribute_Distance=selection Euclidean;Fuzzy Euclidean
##Smallest_Zone_Size=number 1
##Number_of_Zones=number 5
##Zoning_Layer=output vector

library(GeoFIS)

# R script to generate management zones
# See documentation:
# https://www.geofis.org/en/documentation-en/zoning/
# https://cran.r-project.org/web/packages/GeoFIS/vignettes/zoning.html

input <- as_Spatial(Input_Layer)
input@data <- subset(input@data, select = Variable)

zoning <- NewZoning(input)
if (!is.null(Border_Layer)) {
  zoning$border <- as_Spatial(Border_Layer)
}
zoning$neighborhood <- Neighborhood
if (Attribute_Distance == 0) {
  zoning$attribute_distance <- EuclideanDistance()
} else {
  data <- input[[Variable]]
  min <- min(data)
  max <- max(data)
  breakpoints <- c() # adjust values of FisIn breakpoints in the range [min, max]
  fisin <- NewFisIn(breakpoints, min, max) # FisIn object of R package FisPro
  zoning$attribute_distance <- FuzzyDistance(fisin)
}
zoning$smallest_zone <- ZoneSize(Smallest_Zone_Size)

zoning$perform_zoning()

Zoning_Layer <- st_as_sf(zoning$map(Number_of_Zones))
