##GeoFIS=group
##Neighborhood=optional number
##Attribute_Distance=selection Euclidean;Fuzzy Euclidean
##Number_of_Zones=number 5
##Smallest_Zone_Size=number 1
##Zoning_Layer=output vector

library(GeoFIS)

# Example R script to generate management zones, based on the GeoFIS "conductivity_2014" dataset
# See documentation:
# https://www.geofis.org/en/documentation-en/zoning/
# https://cran.r-project.org/web/packages/GeoFIS/vignettes/zoning.html

data(conductivity_2014)
zoning <- NewZoning(conductivity_2014)

data(conductivity_border)
zoning$border <- conductivity_border

zoning$neighborhood <- Neighborhood

if (Attribute_Distance == 0) {
  zoning$attribute_distance <- EuclideanDistance()
} else {
  conduct <- conductivity_2014[["conduct"]]
  min <- min(conduct)
  max <- max(conduct)
  breakpoints <- c(20, 50, 90)
  fisin <- NewFisIn(breakpoints, min, max)
  zoning$attribute_distance <- FuzzyDistance(fisin)
}
zoning$smallest_zone <- ZoneSize(Smallest_Zone_Size)

zoning$perform_zoning()

Zoning_Layer <- st_as_sf(zoning$map(Number_of_Zones))
